==> 0.0.136.tar.gz: lib/screens/forgot_password.dart <==
import 'package:flutter_firebase_basic_tools/widgets/language_picker.dart';
import 'package:flutter_firebase_basic_tools/widgets/topbar.dart';
import 'package:flutter_firebase_basic_tools/widgets/user_info_form_container.dart';
import 'package:flutter_firebase_basic_tools/logic/user_info_form_functions.dart';
import 'package:flutter_firebase_basic_tools/logic/custom_colors.dart';
import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:flutter/material.dart';
import 'package:flutter_firebase_basic_tools/flutter_firebase_basic_tools.dart';
import 'package:shared_preferences/shared_preferences.dart';

class ForgotPassword extends StatefulWidget {
  const ForgotPassword({
    @required this.topbarBackgroundColor,
    @required this.userInfoFormContainerColor1,
    @required this.userInfoFormContainerColor2,
    @required this.userInfoFormContainerColor3,
    @required this.sendEmailButtonColor,
    @required this.itemsTextColor,
    @required this.backgroundImagePath,
    @required this.languagePicker,
    @required this.openLogin,
  });

  final Color topbarBackgroundColor;
  final Color userInfoFormContainerColor1;
  final Color userInfoFormContainerColor2;
  final Color userInfoFormContainerColor3;
  final Color sendEmailButtonColor;
  final Color itemsTextColor;
  final String backgroundImagePath;
  final bool languagePicker;
  final Function openLogin;

  @override
  _ForgotPasswordState createState() => _ForgotPasswordState();
}

class _ForgotPasswordState extends State<ForgotPassword> {
  final GlobalKey<FormState> forgotPasswordFormKey = GlobalKey<FormState>();
  TextEditingController emailInputController = TextEditingController();

  List<String> textList = [
    "Enter your email to change your password",
    "Email",
    "Send password reset email",
  ];

  final GlobalKey<ScaffoldState> scaffoldKey = new GlobalKey<ScaffoldState>();

  String currentLanguage = "en";

  CustomColors customColors = CustomColors();

  TranslationStream translationStream = TranslationStream();

  SharedPreferences prefs;

  updateTextList(int index, String newText) {
    textList[index] = newText;
    setState(() {});
  }

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();
    translationStream.init(textList, updateTextList);
    translationStream.translate();
  }

  languagePickerCallback(String newCurrentLanguage) async {
    currentLanguage = newCurrentLanguage;
    translationStream.translate();
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
  }

  @override
  Widget build(BuildContext context) {
    bool isLandscape =
        (MediaQuery.of(context).orientation == Orientation.landscape);

    double appBarSize = 65;

    return Scaffold(
      key: scaffoldKey,
      extendBodyBehindAppBar: false,
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(appBarSize),
        child: Topbar(
          backgroundColor: widget.topbarBackgroundColor,
          size: appBarSize,
          hasBackButton: true,
          actions: <Widget>[
            Container(
              margin: EdgeInsets.only(right: 20),
              width: isLandscape ? 200 : 100,
              child: widget.languagePicker
                  ? LanguagePicker(
                      currentLanguage: currentLanguage,
                      parentWidget: this,
                      function: languagePickerCallback,
                      itemsTextColor: widget.itemsTextColor,
                    )
                  : Container(),
            ),
          ],
          customLeading: null,
          logoImage: "assets/images/abei_logo.png",
        ),
      ),
      body: UserInfoFormContainer(
        userInfoFormType: UserInfoFormType.forgotPassword,
        cardColor: Colors.white,
        backgroundImagePath: widget.backgroundImagePath,
        linearGradient: LinearGradient(
          begin: FractionalOffset.bottomRight,
          end: FractionalOffset.topLeft,
          colors: [
            widget.userInfoFormContainerColor1,
            widget.userInfoFormContainerColor2,
            widget.userInfoFormContainerColor3,
          ],
          stops: [
            0.0,
            0.4,
            1.0,
          ],
        ),
        child: Form(
          key: forgotPasswordFormKey,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: <Widget>[
              Text(
                'Enter your email for restart your password',
                textAlign: TextAlign.center,
                style: TextStyle(
                  fontSize: 18,
                  fontWeight: FontWeight.bold,
                ),
              ),
              TextFormField(
                decoration: InputDecoration(
                  labelText: 'Email',
                ),
                controller: emailInputController,
                validator: (String value) => FormFieldValidators(
                  value: value,
                  type: FormFieldValidatorsType.email,
                ).validate(),
              ),
              Container(
                width: MediaQuery.of(context).size.width,
                child: RaisedButton(
                  color: widget.sendEmailButtonColor,
                  onPressed: () {
                    UserInfoFormFunctions().forgotPassword(
                      context: context,
                      forgotPasswordFormKey: forgotPasswordFormKey,
                      emailInputController: emailInputController,
                      openLogin: widget.openLogin,
                    );
                  },
                  child: Text(
                    'Send password reset email',
                    textAlign: TextAlign.center,
                    style: TextStyle(
                      color: Colors.white,
                      fontSize: 12,
                      //fontWeight: FontWeight.bold,
                    ),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> 0.0.146.tar.gz: lib/screens/forgot_password.dart <==
import 'package:flutter_firebase_basic_tools/widgets/language_picker.dart';
import 'package:flutter_firebase_basic_tools/widgets/topbar.dart';
import 'package:flutter_firebase_basic_tools/widgets/user_info_form_container.dart';
import 'package:flutter_firebase_basic_tools/logic/user_info_form_functions.dart';

import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:flutter/material.dart';
import 'package:flutter_firebase_basic_tools/flutter_firebase_basic_tools.dart';
import 'package:shared_preferences/shared_preferences.dart';

class ForgotPassword extends StatefulWidget {
  const ForgotPassword({
    @required this.topbarBackgroundColor,
    @required this.userInfoFormContainerColor1,
    @required this.userInfoFormContainerColor2,
    @required this.userInfoFormContainerColor3,
    @required this.sendEmailButtonColor,
    @required this.languagePickerItemsTextColor,
    @required this.backgroundImagePath,
    @required this.languagePicker,
    @required this.openLogin,
  });

  final Color topbarBackgroundColor;
  final Color userInfoFormContainerColor1;
  final Color userInfoFormContainerColor2;
  final Color userInfoFormContainerColor3;
  final Color sendEmailButtonColor;
  final Color languagePickerItemsTextColor;
  final String backgroundImagePath;
  final bool languagePicker;
  final Function openLogin;

  @override
  _ForgotPasswordState createState() => _ForgotPasswordState();
}

class _ForgotPasswordState extends State<ForgotPassword> {
  final GlobalKey<FormState> forgotPasswordFormKey = GlobalKey<FormState>();
  TextEditingController emailInputController = TextEditingController();

  List<String> textList = [
    "Enter your email to change your password",
    "Email",
    "Send password reset email",
  ];

  final GlobalKey<ScaffoldState> scaffoldKey = new GlobalKey<ScaffoldState>();

  String currentLanguage = "en";

  TranslationStream translationStream = TranslationStream();

  SharedPreferences prefs;

  updateTextList(int index, String newText) {
    textList[index] = newText;
    setState(() {});
  }

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();
    translationStream.init(textList, updateTextList);
    translationStream.translate();
  }

  languagePickerCallback(String newCurrentLanguage) async {
    currentLanguage = newCurrentLanguage;
    translationStream.translate();
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
  }

  @override
  Widget build(BuildContext context) {
    bool isLandscape =
        (MediaQuery.of(context).orientation == Orientation.landscape);

    double appBarSize = 65;

    return Scaffold(
      key: scaffoldKey,
      extendBodyBehindAppBar: false,
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(appBarSize),
        child: Topbar(
          backgroundColor: widget.topbarBackgroundColor,
          size: appBarSize,
          hasBackButton: true,
          actions: <Widget>[
            Container(
              margin: EdgeInsets.only(right: 20),
              width: isLandscape ? 200 : 100,
              child: widget.languagePicker
                  ? LanguagePicker(
                      currentLanguage: currentLanguage,
                      parentWidget: this,
                      function: languagePickerCallback,
                      languagePickerItemsTextColor:
                          widget.languagePickerItemsTextColor,
                    )
                  : Container(),
            ),
          ],
          customLeading: null,
          logoImage: "assets/images/abei_logo.png",
        ),
      ),
      body: UserInfoFormContainer(
        userInfoFormType: UserInfoFormType.forgotPassword,
        cardColor: Colors.white,
        backgroundImagePath: widget.backgroundImagePath,
        linearGradient: LinearGradient(
          begin: FractionalOffset.bottomRight,
          end: FractionalOffset.topLeft,
          colors: [
            widget.userInfoFormContainerColor1,
            widget.userInfoFormContainerColor2,
            widget.userInfoFormContainerColor3,
          ],
          stops: [
            0.0,
            0.4,
            1.0,
          ],
        ),
        children: <Widget>[
          Text(
            'Enter your email for restart your password',
            textAlign: TextAlign.center,
            style: TextStyle(
              fontSize: 18,
              fontWeight: FontWeight.bold,
            ),
          ),
          TextFormField(
            decoration: InputDecoration(
              labelText: 'Email',
            ),
            controller: emailInputController,
            validator: (String value) => FormFieldValidators(
              value: value,
              type: FormFieldValidatorsType.email,
            ).validate(),
          ),
          Container(
            width: MediaQuery.of(context).size.width,
            child: RaisedButton(
              color: widget.sendEmailButtonColor,
              onPressed: () {
                UserInfoFormFunctions().forgotPassword(
                  context: context,
                  forgotPasswordFormKey: forgotPasswordFormKey,
                  emailInputController: emailInputController,
                  openLogin: widget.openLogin,
                );
              },
              child: Text(
                'Send password reset email',
                textAlign: TextAlign.center,
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 12,
                  //fontWeight: FontWeight.bold,
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
